package App::PPH21Utils;

use strict;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2023-03-30'; # DATE
our $DIST = 'App-PPH21Utils'; # DIST
our $VERSION = '0.040'; # VERSION

1;
# ABSTRACT: CLI utilities related to Indonesian income tax article 21 ("PPH21")

__END__

=pod

=encoding UTF-8

=head1 NAME

App::PPH21Utils - CLI utilities related to Indonesian income tax article 21 ("PPH21")

=head1 VERSION

This document describes version 0.040 of App::PPH21Utils (from Perl distribution App-PPH21Utils), released on 2023-03-30.

=head1 DESCRIPTION

This distribution includes the following CLI utilities:

=over

=item * L<calc-net-income-from-pph21-op>

=item * L<calc-pph21-op>

=item * L<get-pph21-op-ptkp>

=item * L<get-pph21-op-rates>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-PPH21Utils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-PPH21Utils>.

=head1 SEE ALSO

L<Business::Tax::ID::PPH21>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PPH21Utils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
